@@ -163,19 +163,15 @@ void exit_perl ()
   }
 }
 
-void load_module ()
-{
-  /* perl_eval("use Text::German;"); */
-  perl_require_pv("Text/German.pm");
-  my_module_loaded = 1;
-}
-
 char* grundform _((char *word));
 char* grundform(word)
 char *word;
 {
   if (!my_perl_inited)   init_perl(NULL);
-  if (!my_module_loaded) load_module();
+  if (!my_module_loaded) {
+    require_pv("Text/German.pm");
+    my_module_loaded = 1;
+  }
   return(call_reduce("Text::German::cache_reduce", word));
 }
 
@@ -184,7 +180,10 @@ char* stammform(word)
 char *word;
 {
   if (!my_perl_inited)   init_perl(NULL);
-  if (!my_module_loaded) load_module();
+  if (!my_module_loaded) {
+    require_pv("Text/German.pm");
+    my_module_loaded = 1;
+  }
   return (call_reduce("Text::German::stem", word));
 }
 
